Module processed_jobs
zirv_
queue
0.1.0
Module processed_
jobs
Module Items
Modules
Structs
Constants
Type Aliases
In zirv_
queue::
schema
zirv_queue
::
schema
Module
processed_
jobs
Re-exports

pub use self::
columns
::*;
Modules

columns
Contains all of the columns of this table
dsl
Re-exports all of the columns of this table, as well as the table struct renamed to the module name. This is meant to be glob imported for functions which only deal with one table.
Structs

table
The actual table struct
Constants

all_
columns
A tuple of all of the columns on this table
Type Aliases

Boxed
Query
Helper type for representing a boxed query from this table
SqlType
The SQL type of all of the columns on this table